====================================
ScrapyDD (Scrapy Distributed Daemon)
====================================
Scrapydd is a system for scrapy spiders distributed running and scheduleing system, including server and client agent.
